[llvm-commits] CVS: llvm/lib/Transforms/Utils/InlineFunction.cpp

Chris Lattner sabre at nondot.org
Sun Apr 15 14:38:29 PDT 2007



Changes in directory llvm/lib/Transforms/Utils:

InlineFunction.cpp updated: 1.55 -> 1.56
---
Log message:

Fix PR1335: http://llvm.org/PR1335  and Transforms/Inline/2007-04-15-InlineEH.ll


---
Diffs of the changes:  (+5 -4)

 InlineFunction.cpp |    9 +++++----
 1 files changed, 5 insertions(+), 4 deletions(-)


Index: llvm/lib/Transforms/Utils/InlineFunction.cpp
diff -u llvm/lib/Transforms/Utils/InlineFunction.cpp:1.55 llvm/lib/Transforms/Utils/InlineFunction.cpp:1.56
--- llvm/lib/Transforms/Utils/InlineFunction.cpp:1.55	Thu Mar 22 11:38:57 2007
+++ llvm/lib/Transforms/Utils/InlineFunction.cpp	Sun Apr 15 16:38:06 2007
@@ -69,10 +69,11 @@
           if (!isa<CallInst>(I)) continue;
           CallInst *CI = cast<CallInst>(I);
 
-          // If this is an intrinsic function call, don't convert it to an
-          // invoke.
-          if (CI->getCalledFunction() &&
-              CI->getCalledFunction()->getIntrinsicID())
+          // If this is an intrinsic function call or an inline asm, don't
+          // convert it to an invoke.
+          if ((CI->getCalledFunction() &&
+               CI->getCalledFunction()->getIntrinsicID()) ||
+              isa<InlineAsm>(CI->getCalledValue()))
             continue;
           
           // Convert this function call into an invoke instruction.






More information about the llvm-commits mailing list